+++
title = "Suppress lastmod with auto-set-lastmod"
description = "`lastmod` front-matter parameter is suppressed in this post."
date = 2100-12-21
tags = ["suppress", "lastmod", "nonzero", "autoset"]
draft = false
+++

`org-hugo-suppress-lastmod-period` is set to **172800.0** seconds (2
days) in Local Variables.

_For tests, the "current date" is always Dec 21, 2100._

The export date is set to be the same as the "current date" (so the
delta is 0).
